@@ -12,6 +12,7 @@
 import requests
 import numpy as np
 import json
+from csip import Client
 
 NORM = {
     'kge': lambda x: 1 - x,
@@ -24,8 +25,16 @@ NORM = {
 }
 
 
-def calc_cost(response, objfunc):
+def calc_cost(response: "Client", objfunc) -> float:
     """aggregated objective function value -> cost"""
+
+    # this will eliminate the failed run as a candidate solution.
+    print(response.is_finished())
+    print(response.http_status)
+    print(response.get_metainfo('status'))
+    if not response.is_finished():
+        return np.nan
+
     cost = 0.0
     for of in objfunc:
         of_val = response.get_data_value(of['name'])
